@@ -29,10 +29,10 @@
 #include <CalendarSupport/CollectionSelection>
 #include <CalendarSupport/EventArchiver>
 #include <CalendarSupport/KCalPrefs>
-#include <CalendarSupport/Utils>
 
 #include <IncidenceEditor/IncidenceEditorSettings>
 
+#include <Akonadi/CalendarUtils>
 #include <Akonadi/ETMViewStateSaver>
 #include <Akonadi/EntityDisplayAttribute>
 #include <Akonadi/EntityTreeModel>
@@ -50,6 +50,7 @@
 #include <KMime/KMimeMessage>
 
 #include <KActionCollection>
+#include <KActionMenu>
 #include <KMessageBox>
 #include <KProcess>
 #include <KSelectAction>
@@ -62,13 +63,14 @@
 
 #include "korganizer_debug.h"
 #include "korganizer_options.h"
-#include <KNewStuff3/KNS3/QtQuickDialogWrapper>
+#include <KNSWidgets/Action>
 #include <KToggleAction>
 #include <KWindowSystem>
 #include <QIcon>
 #include <QTemporaryFile>
 
 #include <KCheckableProxyModel>
+#include <KColorSchemeManager>
 #include <KSharedConfig>
 #include <QApplication>
 #include <QStandardPaths>
@@ -246,20 +248,57 @@ void ActionManager::initActions()
     mACollection->addAction(QStringLiteral("import_icalendar"), mImportAction);
     connect(mImportAction, &QAction::triggered, this, &ActionManager::file_import);
 
-    QAction *action = nullptr;
     /** Get Hot New Stuff Action **/
-    // TODO: Icon
-    if (KAuthorized::authorize(QStringLiteral("ghns"))) {
-        action = new QAction(i18n("Get &Hot New Stuff..."), this);
-        action->setStatusTip(i18nc("@info:status", "Load a calendar from \"Get Hot New Stuff\""));
-        action->setToolTip(i18nc("@info:tooltip", "Search \"Get Hot New Stuff\" for calendars to import"));
-        action->setWhatsThis(i18nc("@info:whatsthis",
-                                   "This menu entry opens the \"Get Hot New Stuff\" dialog that allows you "
-                                   "to search and import fun and useful calendars donated to the community."));
-        mACollection->addAction(QStringLiteral("downloadnewstuff"), action);
-        connect(action, &QAction::triggered, this, &ActionManager::downloadNewStuff);
-    }
+    auto knsAction = new KNSWidgets::Action(i18n("Get New Calendars..."), QStringLiteral("korganizer.knsrc"), this);
+    knsAction->setStatusTip(i18nc("@info:status", "Load a calendar from \"Get Hot New Stuff\""));
+    knsAction->setToolTip(i18nc("@info:tooltip", "Search \"Get Hot New Stuff\" for calendars to import"));
+    knsAction->setWhatsThis(i18nc("@info:whatsthis",
+                                  "This menu entry opens the \"Get Hot New Stuff\" dialog that allows you "
+                                  "to search and import fun and useful calendars donated to the community."));
+    mACollection->addAction(QStringLiteral("downloadnewstuff"), knsAction);
+    connect(knsAction, &KNSWidgets::Action::dialogFinished, this, [this](auto changedEntries) {
+        for (const auto &e : changedEntries) {
+            qCDebug(KORGANIZER_LOG) << " downloadNewStuff :";
+            const QStringList lstFile = e.installedFiles();
+            if (lstFile.count() != 1) {
+                continue;
+            }
+            const QString file = lstFile.at(0);
+            const QUrl filename = QUrl::fromLocalFile(file);
+            qCDebug(KORGANIZER_LOG) << "filename :" << filename;
+            if (!filename.isValid()) {
+                continue;
+            }
 
+            KCalendarCore::FileStorage storage(calendar());
+            storage.setFileName(file);
+            storage.setSaveFormat(new KCalendarCore::ICalFormat);
+            if (!storage.load()) {
+                KMessageBox::error(mCalendarView, i18n("Could not load calendar %1.", file));
+            } else {
+                QStringList eventSummaries;
+                const KCalendarCore::Event::List events = calendar()->events();
+                eventSummaries.reserve(events.count());
+                for (const KCalendarCore::Event::Ptr &event : events) {
+                    eventSummaries.append(event->summary());
+                }
+
+                const int result = KMessageBox::warningContinueCancelList(mCalendarView,
+                                                                          i18n("The downloaded events will be merged into your current calendar."),
+                                                                          eventSummaries);
+
+                if (result != KMessageBox::Continue) {
+                    // FIXME (KNS2): hm, no way out here :-)
+                }
+
+                if (importURL(QUrl::fromLocalFile(file), true)) {
+                    // FIXME (KNS2): here neither
+                }
+            }
+        }
+    });
+
+    QAction *action = nullptr;
     /** Export Action **/
     // TODO: Icon
     action = new QAction(i18n("Export as &iCalendar..."), this);
@@ -301,14 +340,28 @@ void ActionManager::initActions()
         mCutAction = mACollection->addAction(KStandardAction::Cut, QStringLiteral("korganizer_cut"), mCalendarView, &CalendarView::edit_cut);
         mCopyAction = mACollection->addAction(KStandardAction::Copy, QStringLiteral("korganizer_copy"), mCalendarView, &CalendarView::edit_copy);
         pasteAction = mACollection->addAction(KStandardAction::Paste, QStringLiteral("korganizer_paste"), mCalendarView, &CalendarView::edit_paste);
-        mUndoAction = mACollection->addAction(KStandardAction::Undo, QStringLiteral("korganizer_undo"), this, [=](){history->undo();});
-        mRedoAction = mACollection->addAction(KStandardAction::Redo, QStringLiteral("korganizer_redo"), this, [=](){history->redo();});
+        mUndoAction = mACollection->addAction(KStandardAction::Undo, QStringLiteral("korganizer_undo"), this, [=]() {
+            history->undo();
+        });
+        mRedoAction = mACollection->addAction(KStandardAction::Redo, QStringLiteral("korganizer_redo"), this, [=]() {
+            history->redo();
+        });
     } else {
         mCutAction = KStandardAction::cut(mCalendarView, &CalendarView::edit_cut, mACollection);
         mCopyAction = KStandardAction::copy(mCalendarView, &CalendarView::edit_copy, mACollection);
         pasteAction = KStandardAction::paste(mCalendarView, &CalendarView::edit_paste, mACollection);
-        mUndoAction = KStandardAction::undo(this, [=](){history->undo();}, mACollection);
-        mRedoAction = KStandardAction::redo(this, [=](){history->redo();}, mACollection);
+        mUndoAction = KStandardAction::undo(
+            this,
+            [=]() {
+                history->undo();
+            },
+            mACollection);
+        mRedoAction = KStandardAction::redo(
+            this,
+            [=]() {
+                history->redo();
+            },
+            mACollection);
     }
     mDeleteAction = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("&Delete"), this);
     mACollection->addAction(QStringLiteral("edit_delete"), mDeleteAction);
@@ -326,7 +379,7 @@ void ActionManager::initActions()
 
     /************************** VIEW MENU *********************************/
 
-    /** Whats Next View Action **/
+    /** What's Next View Action **/
     action = new QAction(QIcon::fromTheme(QStringLiteral("view-calendar-upcoming-events")), i18n("What's &Next"), this);
     action->setStatusTip(i18nc("@info:status", "What's Next View"));
     action->setToolTip(i18nc("@info:tooltip", "Switch to the What's Next View"));
@@ -477,7 +530,7 @@ void ActionManager::initActions()
 
     /** Scroll Forward Action **/
     action = new QAction(QIcon::fromTheme(isRTL ? QStringLiteral("go-previous") : QStringLiteral("go-next")), i18nc("scroll forward", "&Forward"), this);
-    action->setIconText(i18nc("scoll forward", "Forward"));
+    action->setIconText(i18nc("scroll forward", "Forward"));
     action->setStatusTip(i18nc("@info:status", "Scroll Forward"));
     action->setToolTip(i18nc("@info:tooltip", "Scroll the view forward"));
     action->setWhatsThis(i18nc("@info:whatsthis",
@@ -584,36 +637,48 @@ void ActionManager::initActions()
     /************************** SCHEDULE MENU ********************************/
     mPublishEvent = new QAction(QIcon::fromTheme(QStringLiteral("mail-send")), i18n("&Publish Item Information..."), this);
     mACollection->addAction(QStringLiteral("schedule_publish"), mPublishEvent);
-    connect(mPublishEvent, &QAction::triggered, this, [=](bool){mCalendarView->schedule_publish();});
+    connect(mPublishEvent, &QAction::triggered, this, [=](bool) {
+        mCalendarView->schedule_publish();
+    });
     mPublishEvent->setEnabled(false);
 
     mSendInvitation = new QAction(QIcon::fromTheme(QStringLiteral("mail-send")), i18n("Send &Invitation to Attendees"), this);
     mACollection->addAction(QStringLiteral("schedule_request"), mSendInvitation);
-    connect(mSendInvitation, &QAction::triggered, this, [=](bool){mCalendarView->schedule_request();});
+    connect(mSendInvitation, &QAction::triggered, this, [=](bool) {
+        mCalendarView->schedule_request();
+    });
     mSendInvitation->setEnabled(false);
     connect(mCalendarView, &CalendarView::organizerEventsSelected, mSendInvitation, &QAction::setEnabled);
 
     mRequestUpdate = new QAction(i18n("Re&quest Update"), this);
     mACollection->addAction(QStringLiteral("schedule_refresh"), mRequestUpdate);
-    connect(mRequestUpdate, &QAction::triggered, this, [=](bool){mCalendarView->schedule_refresh();});
+    connect(mRequestUpdate, &QAction::triggered, this, [=](bool) {
+        mCalendarView->schedule_refresh();
+    });
     mRequestUpdate->setEnabled(false);
     connect(mCalendarView, &CalendarView::groupEventsSelected, mRequestUpdate, &QAction::setEnabled);
 
     mSendCancel = new QAction(i18n("Send &Cancellation to Attendees"), this);
     mACollection->addAction(QStringLiteral("schedule_cancel"), mSendCancel);
-    connect(mSendCancel, &QAction::triggered, this, [=](bool){mCalendarView->schedule_cancel();});
+    connect(mSendCancel, &QAction::triggered, this, [=](bool) {
+        mCalendarView->schedule_cancel();
+    });
     mSendCancel->setEnabled(false);
     connect(mCalendarView, &CalendarView::organizerEventsSelected, mSendCancel, &QAction::setEnabled);
 
     mSendStatusUpdate = new QAction(QIcon::fromTheme(QStringLiteral("mail-reply-sender")), i18n("Send Status &Update"), this);
     mACollection->addAction(QStringLiteral("schedule_reply"), mSendStatusUpdate);
-    connect(mSendStatusUpdate, &QAction::triggered, this, [=](bool){mCalendarView->schedule_reply();});
+    connect(mSendStatusUpdate, &QAction::triggered, this, [=](bool) {
+        mCalendarView->schedule_reply();
+    });
     mSendStatusUpdate->setEnabled(false);
     connect(mCalendarView, &CalendarView::groupEventsSelected, mSendStatusUpdate, &QAction::setEnabled);
 
     mRequestChange = new QAction(i18nc("counter proposal", "Request Chan&ge"), this);
     mACollection->addAction(QStringLiteral("schedule_counter"), mRequestChange);
-    connect(mRequestChange, &QAction::triggered, this, [=](bool){mCalendarView->schedule_counter();});
+    connect(mRequestChange, &QAction::triggered, this, [=](bool) {
+        mCalendarView->schedule_counter();
+    });
     mRequestChange->setEnabled(false);
     connect(mCalendarView, &CalendarView::groupEventsSelected, mRequestChange, &QAction::setEnabled);
 
@@ -624,7 +689,9 @@ void ActionManager::initActions()
 
     mForwardEvent = new QAction(QIcon::fromTheme(QStringLiteral("mail-forward")), i18n("&Send as iCalendar..."), this);
     mACollection->addAction(QStringLiteral("schedule_forward"), mForwardEvent);
-    connect(mForwardEvent, &QAction::triggered, this, [=](bool){mCalendarView->schedule_forward();});
+    connect(mForwardEvent, &QAction::triggered, this, [=](bool) {
+        mCalendarView->schedule_forward();
+    });
     mForwardEvent->setEnabled(false);
 
     action = new QAction(i18n("&Upload Free Busy Information"), this);
@@ -690,6 +757,9 @@ void ActionManager::initActions()
     mACollection->addAction(QStringLiteral("edit_categories"), action);
     connect(action, &QAction::triggered, mCalendarView->dialogManager(), &KODialogManager::showCategoryEditDialog);
 
+    auto manager = new KColorSchemeManager(this);
+    mACollection->addAction(QStringLiteral("colorscheme_menu"), manager->createSchemeSelectionMenu(this));
+
     if (mIsPart) {
         action = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("&Configure KOrganizer..."), this);
         mACollection->addAction(QStringLiteral("korganizer_configure"), action);
@@ -1162,49 +1232,6 @@ bool ActionManager::addIncidence(const QString &ical)
     return mCalendarView->addIncidence(ical);
 }
 
-void ActionManager::downloadNewStuff()
-{
-    const auto installedEntries = KNS3::QtQuickDialogWrapper(QStringLiteral("korganizer.knsrc")).exec();
-    for (const auto &e : installedEntries) {
-        qCDebug(KORGANIZER_LOG) << " downloadNewStuff :";
-        const QStringList lstFile = e.installedFiles();
-        if (lstFile.count() != 1) {
-            continue;
-        }
-        const QString file = lstFile.at(0);
-        const QUrl filename = QUrl::fromLocalFile(file);
-        qCDebug(KORGANIZER_LOG) << "filename :" << filename;
-        if (!filename.isValid()) {
-            continue;
-        }
-
-        KCalendarCore::FileStorage storage(calendar());
-        storage.setFileName(file);
-        storage.setSaveFormat(new KCalendarCore::ICalFormat);
-        if (!storage.load()) {
-            KMessageBox::error(mCalendarView, i18n("Could not load calendar %1.", file));
-        } else {
-            QStringList eventSummaries;
-            const KCalendarCore::Event::List events = calendar()->events();
-            eventSummaries.reserve(events.count());
-            for (const KCalendarCore::Event::Ptr &event : events) {
-                eventSummaries.append(event->summary());
-            }
-
-            const int result =
-                KMessageBox::warningContinueCancelList(mCalendarView, i18n("The downloaded events will be merged into your current calendar."), eventSummaries);
-
-            if (result != KMessageBox::Continue) {
-                // FIXME (KNS2): hm, no way out here :-)
-            }
-
-            if (importURL(QUrl::fromLocalFile(file), true)) {
-                // FIXME (KNS2): here neither
-            }
-        }
-    }
-}
-
 QString ActionManager::localFileName() const
 {
     return mFile;
@@ -1287,7 +1314,7 @@ void ActionManager::processIncidenceSelection(const Akonadi::Item &item, QDate d
     // qCDebug(KORGANIZER_LOG) << "ActionManager::processIncidenceSelection()";
     Q_UNUSED(date)
 
-    const KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
+    const KCalendarCore::Incidence::Ptr incidence = Akonadi::CalendarUtils::incidence(item);
     if (!incidence) {
         enableIncidenceActions(false);
         return;
