@@ -135,7 +135,7 @@ public:
       Show an incidence in context, given its uid.
       @param uid the iCal uid of the incidence to show.
     */
-    void showIncidenceByUid(const QString &uid, const QDateTime &occurence, const QString &xdgActivationToken);
+    void showIncidenceByUid(const QString &uid, const QDateTime &occurrence, const QString &xdgActivationToken);
 
     /**
      * Called by KOrganizerUniqueAppHandler in the kontact plugin
@@ -253,8 +253,6 @@ protected Q_SLOTS:
     /** Open kcontrol module for configuring date and time formats */
     void configureDateTime();
 
-    void downloadNewStuff();
-
     void toggleDateNavigator();
     void toggleTodoView();
     void toggleEventViewer();
@@ -363,4 +361,3 @@ private:
     KViewStateMaintainer<Akonadi::ETMViewStateSaver> *mCollectionSelectionModelStateSaver = nullptr;
     KHamburgerMenu *mHamburgerMenu = nullptr;
 };
-
