@@ -20,7 +20,6 @@
 #include "korganizer_options.h"
 
 #include <QCommandLineParser>
-#include <QDBusConnectionInterface>
 
 #include <Akonadi/ItemFetchJob>
 #include <Akonadi/ItemFetchScope>
@@ -50,8 +49,6 @@ int KOrganizerApp::activate(const QStringList &args, const QString &workingDir)
     }
     first = false;
 
-    QDBusConnection::sessionBus().interface()->startService(QStringLiteral("org.kde.kalendarac"));
-
     QCommandLineParser parser;
     korganizer_options(&parser);
     parser.process(args);
