@@ -20,7 +20,7 @@ class TodoPlugin : public KontactInterface::Plugin
 {
     Q_OBJECT
 public:
-    TodoPlugin(KontactInterface::Core *core, const QVariantList &);
+    TodoPlugin(KontactInterface::Core *core, const KPluginMetaData &data, const QVariantList &);
     ~TodoPlugin() override;
 
     Q_REQUIRED_RESULT bool isRunningStandalone() const override;
@@ -50,4 +50,3 @@ private:
     OrgKdeKorganizerCalendarInterface *mIface = nullptr;
     KontactInterface::UniqueAppWatcher *mUniqueAppWatcher = nullptr;
 };
-
