@@ -7,18 +7,16 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KOPREFSDIALOGGROUPSCHEDULING_H
-#define KOPREFSDIALOGGROUPSCHEDULING_H
+#pragma once
 
 #include "kprefsdialog.h"
 class KOPrefsDialogGroupScheduling : public Korganizer::KPrefsModule
 {
     Q_OBJECT
 public:
-    explicit KOPrefsDialogGroupScheduling(QWidget *parent);
+    explicit KOPrefsDialogGroupScheduling(QWidget *parent, const QVariantList &args = {});
 
 protected:
     void usrWriteConfig() override;
     void usrReadConfig() override;
 };
-#endif // KOPREFSDIALOGGROUPSCHEDULING_H
